Export Package VRC : bcB61Ma1ca02
Update compared VRC:   B61Xa ca02
Only Package       : Yes
Based on sessions  : No
Script sources     : No
Function  sources  : No
Library sources    : No
Creation Date      : 113006 00:09:15
Total file size    : 1701861
---------------------------------------
C = Charts
q = Questions
c = Messages
l = Labels
d = Domains
t = Table Definitions
s = Sessions
p = Scripts
o = Objects
f = Forms
F = Form Dumps
m = Menus
M = Menu Dumps
r = Reports
i = Impl. Functions
S = Subscription Templates
b = Functions
A = Additional Files
h = Help Text Codes
----------------------
tbcttf001                                             B61Ma1ca02 (not expired)
tbcttf002                                             B61Ma1ca02 (not expired)
tbcttf005                                             B61Ma1ca02 (not expired)
sbccor0201m000                                        B61Ma ca02 (not expired)
sbccor0202m000                                        B61Ma ca02 (not expired)
sbccor0205m000                                        B61Ma ca02 (not expired)
sbccor0208m000                                        B61Ma1ca02 (not expired)
sbccor0213m000                                        B61Ma ca02 (not expired)
sbccor0215m000                                        B61Ma1ca02 (not expired)
sbccor0217m000                                        B61Ma ca02 (not expired)
sbccor0218m000                                        B61Ma ca02 (not expired)
sbccor0219m000                                        B61Ma1ca02 (not expired)
sbccor0221m000                                        B61Ma1ca02 (not expired)
sbccor0222m000                                        B61Ma1ca02 (not expired)
sbcttc0201m000                                        B61Ma1ca02 (not expired)
sbcttf0105m000                                        B61Ma1ca02 (not expired)
sbcttf0201m000                                        B61Ma1ca02 (not expired)
sbctti0202m000                                        B61Ma1ca02 (not expired)
sbctti0203m000                                        B61Ma1ca02 (not expired)
pbccor0001                                            B61Ma ca02 (without source) (not expired)
pbccor0200                                            B61Ma ca02 (without source) (not expired)
pbccor0201                                            B61Ma ca02 (without source) (not expired)
pbccor0202                                            B61Ma ca02 (without source) (not expired)
pbccor0203                                            B61Ma ca02 (without source) (not expired)
pbccor0204                                            B61Ma ca02 (without source) (not expired)
pbccor0205                                            B61Ma ca02 (without source) (not expired)
pbccor0206                                            B61Ma1ca02 (without source) (not expired)
pbccor0207                                            B61Ma ca02 (without source) (not expired)
pbccor0208                                            B61Ma1ca02 (without source) (not expired)
pbccor0210                                            B61Ma ca02 (without source) (not expired)
pbccor0211                                            B61Ma ca02 (without source) (not expired)
pbccor0212                                            B61Ma ca02 (without source) (not expired)
pbccor0213                                            B61Ma ca02 (without source) (not expired)
pbccor0215                                            B61Ma1ca02 (without source) (not expired)
pbccor0216                                            B61Ma ca02 (without source) (not expired)
pbccor0217                                            B61Ma ca02 (without source) (not expired)
pbccor0218                                            B61Ma ca02 (without source) (not expired)
pbccor0219                                            B61Ma1ca02 (without source) (not expired)
pbccor0220                                            B61Ma1ca02 (without source) (not expired)
pbccor0221                                            B61Ma1ca02 (without source) (not expired)
pbccor0222                                            B61Ma1ca02 (without source) (not expired)
pbccor0223                                            B61Ma1ca02 (without source) (not expired)
pbccortestgz                                          B61Ma ca02 (without source) (expired)
pbccorts220                                           B61Ma ca02 (without source) (not expired)
pbcttc0201                                            B61Ma1ca02 (without source) (not expired)
pbcttcdll0001                                         B61Ma1ca02 (without source) (not expired)
pbcttf0201                                            B61Ma1ca02 (without source) (not expired)
pbcttf1206                                            B61Ma ca02 (without source) (not expired)
pbcttfdll0001                                         B61Ma1ca02 (without source) (not expired)
pbcttfdll0002                                         B61Ma1ca02 (without source) (not expired)
pbcttfdll0003                                         B61Ma ca02 (without source) (not expired)
pbcttfdll0004                                         B61Ma ca02 (without source) (not expired)
pbcttfdll0005                                         B61Ma1ca02 (without source) (not expired)
pbcttfdll0006                                         B61Ma1ca02 (without source) (not expired)
pbcttfdll0008                                         B61Ma1ca02 (without source) (not expired)
pbctti0202                                            B61Ma1ca02 (without source) (not expired)
pbctti0203                                            B61Ma1ca02 (without source) (not expired)
pbcttidll0002                                         B61Ma1ca02 (without source) (not expired)
pbcttidll0003                                         B61Ma1ca02 (without source) (not expired)
pbcttidll0004                                         B61Ma1ca02 (without source) (not expired)
pbcttt9200                                            B61Ma ca02 (without source) (not expired)
fbccor0201m000d2                                      B61Ma ca02 (not expired)
fbccor0202m000d2                                      B61Ma ca02 (not expired)
fbccor0205m000d2                                      B61Ma ca02 (not expired)
fbccor0208m000d2                                      B61Ma1ca02 (not expired)
fbccor0213m000d2                                      B61Ma ca02 (not expired)
fbccor0215m000d2                                      B61Ma1ca02 (not expired)
fbccor0217m000d2                                      B61Ma ca02 (not expired)
fbccor0218m000d2                                      B61Ma ca02 (not expired)
fbccor0219m000d2                                      B61Ma1ca02 (not expired)
fbccor0221m000d2                                      B61Ma1ca02 (not expired)
fbccor0222m000d2                                      B61Ma1ca02 (not expired)
fbcttc0201m000d2                                      B61Ma1ca02 (not expired)
fbcttf0105m000d2                                      B61Ma1ca02 (not expired)
fbcttf0201m000d2                                      B61Ma1ca02 (not expired)
fbctti0202m000d2                                      B61Ma1ca02 (not expired)
fbctti0203m000d2                                      B61Ma1ca02 (not expired)
rbccor0201010002                                      B61Ma ca02 (not expired)
rbccor0202010002                                      B61Ma ca02 (not expired)
rbccor0205110002                                      B61Ma ca02 (not expired)
rbccor0208110002                                      B61Ma1ca02 (not expired)
rbccor0213110002                                      B61Ma ca02 (not expired)
rbccor0215110002                                      B61Ma1ca02 (not expired)
rbccor0217110002                                      B61Ma ca02 (not expired)
rbccor0218110002                                      B61Ma ca02 (not expired)
rbccor0219110002                                      B61Ma1ca02 (not expired)
rbccor0221110002                                      B61Ma1ca02 (not expired)
rbccor0222110002                                      B61Ma1ca02 (not expired)
rbctti0202010002                                      B61Ma1ca02 (not expired)
rbctti0202020002                                      B61Ma1ca02 (not expired)
rbctti0203010002                                      B61Ma1ca02 (not expired)
rbctti0203020002                                      B61Ma1ca02 (not expired)
cbccor0001                                            B61Ma ca02 (not expired)
cbctti0202.01                                         B61Ma1ca02 (not expired)
cbctti0203.01                                         B61Ma1ca02 (not expired)
bbcbic___slm___                                       B61Ma1ca02 (with source) (not expired)
obccnv5272                                            B61Ma1ca02
obccor0001                                            B61Ma ca02
obccor0200                                            B61Ma ca02
obccor0201                                            B61Ma ca02
obccor0202                                            B61Ma ca02
obccor0203                                            B61Ma ca02
obccor0204                                            B61Ma ca02
obccor0205                                            B61Ma ca02
obccor0206                                            B61Ma1ca02
obccor0207                                            B61Ma ca02
obccor0208                                            B61Ma1ca02
obccor0210                                            B61Ma ca02
obccor0211                                            B61Ma ca02
obccor0212                                            B61Ma ca02
obccor0213                                            B61Ma ca02
obccor0215                                            B61Ma1ca02
obccor0216                                            B61Ma ca02
obccor0217                                            B61Ma ca02
obccor0218                                            B61Ma ca02
obccor0219                                            B61Ma1ca02
obccor0220                                            B61Ma1ca02
obccor0221                                            B61Ma1ca02
obccor0222                                            B61Ma1ca02
obccor0223                                            B61Ma1ca02
obccortestgz                                          B61Ma ca02
obccorts220                                           B61Ma ca02
obcgct8189                                            B61Ma1ca02
obcgct8289                                            B61Ma1ca02
obcrun90502                                           B61Ma1ca02
obcttc0100                                            B61Ma1ca02
obcttc0201                                            B61Ma1ca02
obcttcdll0001                                         B61Ma1ca02
obcttcdll0002                                         B61Ma1ca02
obcttf0105                                            B61Ma1ca02
obcttf0110                                            B61Ma1ca02
obcttf0201                                            B61Ma1ca02
obcttf0220                                            B61Ma1ca02
obcttf1206                                            B61Ma ca02
obcttfdll0001                                         B61Ma1ca02
obcttfdll0002                                         B61Ma1ca02
obcttfdll0003                                         B61Ma1ca02
obcttfdll0004                                         B61Ma ca02
obcttfdll0005                                         B61Ma1ca02
obcttfdll0006                                         B61Ma1ca02
obcttfdll0007                                         B61Ma1ca02
obcttfdll0008                                         B61Ma1ca02
obctti0201                                            B61Ma1ca02
obctti0202                                            B61Ma1ca02
obctti0203                                            B61Ma1ca02
obcttidll0001                                         B61Ma1ca02
obcttidll0002                                         B61Ma1ca02
obcttidll0003                                         B61Ma1ca02
obcttidll0004                                         B61Ma1ca02
obcttt9200                                            B61Ma ca02
obctttdll0001                                         B61Ma1ca02
obccor0201010002                                      B61Ma ca02
obccor0202010002                                      B61Ma ca02
obccor0205110002                                      B61Ma ca02
obccor0208110002                                      B61Ma1ca02
obccor0213110002                                      B61Ma ca02
obccor0215110002                                      B61Ma1ca02
obccor0217110002                                      B61Ma ca02
obccor0218110002                                      B61Ma ca02
obccor0219110002                                      B61Ma1ca02
obccor0221110002                                      B61Ma1ca02
obccor0222110002                                      B61Ma1ca02
obctti0202010002                                      B61Ma1ca02
obctti0202020002                                      B61Ma1ca02
obctti0203010002                                      B61Ma1ca02
obctti0203020002                                      B61Ma1ca02
lbcbc.item.from     109                               B61Ma ca02 (not expired)
lbcbccor0201.01     131                               B61Ma ca02 (not expired)
lbcbccors0205.01    116                               B61Ma ca02 (not expired)
lbcbccors0205.02    216                               B61Ma ca02 (not expired)
lbcbccors0205.03    216                               B61Ma ca02 (not expired)
lbcbcgen.blocked    107                               B61Ma1ca02 (not expired)
lbcbcgen.blocked.ep 114                               B61Ma1ca02 (not expired)
lbcbcgen.committed  109                               B61Ma1ca02 (not expired)
lbcbcgen.committed.p120                               B61Ma1ca02 (not expired)
lbcbcgen.loc.alloc  118                               B61Ma1ca02 (not expired)
lbcbcgen.onhand     107                               B61Ma1ca02 (not expired)
lbcbcttc0201.17     141                               B61Ma1ca02 (not expired)
lbcbcttf001.cvat.f  108                               B61Ma1ca02 (not expired)
lbcbcttf020.line    118                               B61Ma ca02 (not expired)
lbcbctti0202.01     148                               B61Ma1ca02 (not expired)
lbccor020101000001  140                               B61Ma ca02 (not expired)
lbccor020101000002  140                               B61Ma ca02 (not expired)
lbccor0201m000001   140                               B61Ma ca02 (not expired)
lbccor0202001       130                               B61Ma ca02 (not expired)
lbccor020201000001  130                               B61Ma ca02 (not expired)
lbccor020201000002  130                               B61Ma ca02 (not expired)
lbccor020201000003  130                               B61Ma ca02 (not expired)
lbccor020201000004  132                               B61Ma ca02 (not expired)
lbccor020201000005  132                               B61Ma ca02 (not expired)
lbccor020201000006  130                               B61Ma ca02 (not expired)
lbccor020201000007  151                               B61Ma ca02 (not expired)
lbccor0202m000001   130                               B61Ma ca02 (not expired)
lbccor020511000001  146                               B61Ma ca02 (not expired)
lbccor0205m000001   146                               B61Ma ca02 (not expired)
lbccor020811000001  156                               B61Ma1ca02 (not expired)
lbccor0208m000001   156                               B61Ma1ca02 (not expired)
lbccor021311000001  143                               B61Ma ca02 (not expired)
lbccor0213m000001   162                               B61Ma ca02 (not expired)
lbccor0213m000002   143                               B61Ma ca02 (not expired)
lbccor021511000001  156                               B61Ma1ca02 (not expired)
lbccor0215m000001   133                               B61Ma1ca02 (not expired)
lbccor0215m000002   156                               B61Ma1ca02 (not expired)
lbccor021711000001  152                               B61Ma ca02 (not expired)
lbccor0217m000001   152                               B61Ma ca02 (not expired)
lbccor021811000001  153                               B61Ma ca02 (not expired)
lbccor0218m000001   160                               B61Ma ca02 (not expired)
lbccor021911000001  126                               B61Ma1ca02 (not expired)
lbccor0219m000001   142                               B61Ma1ca02 (not expired)
lbccor022111000001  156                               B61Ma1ca02 (not expired)
lbccor0221m000001   139                               B61Ma1ca02 (not expired)
lbccor022211000001  159                               B61Ma1ca02 (not expired)
lbccor0222m000001   132                               B61Ma1ca02 (not expired)
lbcitem.to          107                               B61Ma ca02 (not expired)
lbcloca             108                               B61Ma ca02 (not expired)
lbclot              103                               B61Ma ca02 (not expired)
lbcsimulate         108                               B61Ma ca02 (not expired)
lbcstorage.data     112                               B61Ma ca02 (not expired)
lbctrans.date       211                               B61Ma ca02 (not expired)
lbcttd0000001 1001  116                               B61Ma1ca02 (not expired)
lbcttd000010011001  116                               B61Ma1ca02 (not expired)
lbcttf.aext         115                               B61Ma ca02 (not expired)
lbcttf.anbr         112                               B61Ma ca02 (not expired)
lbcttf.book         110                               B61Ma ca02 (not expired)
lbcttf.meth         119                               B61Ma ca02 (not expired)
lbctti001001        138                               B61Ma1ca02 (not expired)
lbctti020201000001  157                               B61Ma1ca02 (not expired)
lbctti020202000001  160                               B61Ma1ca02 (not expired)
lbctti0202m000001   142                               B61Ma1ca02 (not expired)
lbctti020301000001  156                               B61Ma1ca02 (not expired)
lbctti020302000001  160                               B61Ma1ca02 (not expired)
lbctti0203m000001   123                               B61Ma1ca02 (not expired)
lbcwh.receipt       130                               B61Ma ca02 (not expired)
lbcwhinh220.qshp    116                               B61Ma ca02 (not expired)
Fbccor0201m000d2                                      B61Ma ca02
Fbccor0202m000d2                                      B61Ma ca02
Fbccor0205m000d2                                      B61Ma ca02
Fbccor0208m000d2                                      B61Ma1ca02
Fbccor0213m000d2                                      B61Ma ca02
Fbccor0215m000d2                                      B61Ma1ca02
Fbccor0217m000d2                                      B61Ma ca02
Fbccor0218m000d2                                      B61Ma ca02
Fbccor0219m000d2                                      B61Ma1ca02
Fbccor0221m000d2                                      B61Ma1ca02
Fbccor0222m000d2                                      B61Ma1ca02
Fbcttc0201m000d2                                      B61Ma1ca02
Fbcttf0105m000d2                                      B61Ma1ca02
Fbcttf0201m000d2                                      B61Ma1ca02
Fbctti0202m000d2                                      B61Ma1ca02
Fbctti0203m000d2                                      B61Ma1ca02
Mbcttc0000000212                                      B61Ma1ca02
Mbcttd0000100112                                      B61Ma1ca02
Mbcttf0000200112                                      B61Ma1ca02
Mbctti0000100112                                      B61Ma1ca02
